@@ -56,13 +56,13 @@ static GList *gda_default_provider_execute_command (GdaServerProvider *provider,
 						    GdaParameterList *params);
 static gboolean gda_default_provider_begin_transaction (GdaServerProvider *provider,
 							GdaConnection *cnc,
-							const gchar *trans_id);
+							GdaTransaction *xaction);
 static gboolean gda_default_provider_commit_transaction (GdaServerProvider *provider,
 							 GdaConnection *cnc,
-							 const gchar *trans_id);
+							 GdaTransaction *xaction);
 static gboolean gda_default_provider_rollback_transaction (GdaServerProvider *provider,
 							   GdaConnection *cnc,
-							   const gchar *trans_id);
+							   GdaTransaction *xaction);
 static gboolean gda_default_provider_supports (GdaServerProvider *provider,
 					       GdaConnection *cnc,
 					       GdaConnectionFeature feature);
@@ -281,7 +281,7 @@ gda_default_provider_execute_command (GdaServerProvider *provider,
 static gboolean
 gda_default_provider_begin_transaction (GdaServerProvider *provider,
 					GdaConnection *cnc,
-					const gchar *trans_id)
+					GdaTransaction *xaction)
 {
 	GdaXmlDatabase *xmldb;
 	GdaDefaultProvider *dfprv = (GdaDefaultProvider *) provider;
@@ -299,7 +299,7 @@ gda_default_provider_begin_transaction (GdaServerProvider *provider,
 static gboolean
 gda_default_provider_commit_transaction (GdaServerProvider *provider,
 					 GdaConnection *cnc,
-					 const gchar *trans_id)
+					 GdaTransaction *xaction)
 {
 	GdaXmlDatabase *xmldb;
 	GdaDefaultProvider *dfprv = (GdaDefaultProvider *) provider;
@@ -317,7 +317,7 @@ gda_default_provider_commit_transaction (GdaServerProvider *provider,
 static gboolean
 gda_default_provider_rollback_transaction (GdaServerProvider *provider,
 					   GdaConnection *cnc,
-					   const gchar *trans_id)
+					   GdaTransaction *xaction)
 {
 	GdaXmlDatabase *xmldb;
 	GdaDefaultProvider *dfprv = (GdaDefaultProvider *) provider;
